@@ -356,6 +356,7 @@ class Company(models.Model):
     :country: The country, this company is in.
     :code: A short identifier for this company.
     :description: Full company description (name).
+    :shipping_days: How many shipping days this company needs.
 
     reverse relations:
     :cboms: All the CBOMs related to this company.
@@ -378,6 +379,11 @@ class Company(models.Model):
         max_length=128,
     )
 
+    shipping_days = models.PositiveIntegerField(
+        verbose_name=_('shipping days'),
+        blank=True, null=True,
+    )
+
     def __unicode__(self):
         return u'Customer "{0}"'.format(self.description)
 
@@ -494,6 +500,8 @@ class IPN(models.Model):
     :name: A name for this IPN.
     :price_group: The price group, this IPN is in.
     :shape: TODO
+    :technology: What technology this IPN is.
+    :product: What product this IPN belongs to.
 
     reverse relations:
     :additional_texts: The list of AdditionalText objects attached.
@@ -531,6 +539,20 @@ class IPN(models.Model):
         related_name='ipns',
     )
 
+    technology = models.ForeignKey(
+        'aps_bom.Technology',
+        verbose_name=_('technology'),
+        related_name='ipns',
+        blank=True, null=True,
+    )
+
+    product = models.ForeignKey(
+        'aps_bom.Product',
+        verbose_name=_('product'),
+        related_name='ipns',
+        blank=True, null=True,
+    )
+
     objects = IPNManager()
 
     @property
@@ -616,6 +638,32 @@ class PriceMarker(models.Model):
             self.price, self.ipn.code, self.date)
 
 
+class Product(models.Model):
+    """
+    Something, that is actually sold.
+
+    :product_number: A unique string, that identifies the product
+    :description: The product's description
+
+    """
+    product_number = models.CharField(
+        verbose_name=_('product number'),
+        max_length=256,
+        unique=True,
+    )
+
+    description = models.TextField(
+        verbose_name=_('description'),
+        blank=True,
+    )
+
+    def __unicode__(self):
+        return self.product_number
+
+    class Meta:
+        ordering = ('product_number', )
+
+
 class Shape(models.Model):
     """
     TODO
@@ -645,6 +693,33 @@ class Shape(models.Model):
         ordering = ('code', )
 
 
+class Technology(models.Model):
+    """
+    Describes, what kind of product a certain IPN is.
+
+    :identifier: A short string to identify the technology.
+    :description: descriptive text.
+
+    """
+
+    identifier = models.CharField(
+        verbose_name=_('identifier'),
+        max_length=3,
+        unique=True,
+    )
+
+    description = models.TextField(
+        verbose_name=_('description'),
+        blank=True,
+    )
+
+    def __unicode__(self):
+        return self.identifier
+
+    class Meta:
+        ordering = ('identifier', )
+
+
 class Unit(models.Model):
     """
     The unit a qty can be in. (see e.g. BOMItem)
