@@ -7,6 +7,10 @@ BOM_CSV_FIELDNAMES = getattr(settings, 'APS_BOM_BOM_CSV_FIELDNAMES',
                              ["Position", "IPN", "Description", "QTY", "Unit",
                               "Shape"])
 
+CBOM_CSV_FIELDNAMES = getattr(settings, 'APS_BOM_BOM_CSV_FIELDNAMES',
+                              ["Position", "EPN", "Description", "QTY", "Unit",
+                               "consign"])
+
 BOM_UPLOAD_SUCCESS_URL = getattr(settings,
                                  'APS_BOM_BOM_UPLOAD_VIEW_SUCCESS_URL',
                                  reverse_lazy('aps_bom_bom_upload'))
